Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1047)

Unified Diff: webkit/glue/webview_delegate.h

Issue 155954: Implement sending actions back to the render for media element context menus. (Closed)
Patch Set: remove uneeded bits. Created 11 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/glue/webview.h ('k') | webkit/glue/webview_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/webview_delegate.h
diff --git a/webkit/glue/webview_delegate.h b/webkit/glue/webview_delegate.h
index 77624b3054392f3582a0af8524219e271075d7a9..8f2371b3681400d1cdea062c6d5f5d1a2ed081db 100644
--- a/webkit/glue/webview_delegate.h
+++ b/webkit/glue/webview_delegate.h
@@ -50,6 +50,7 @@ class WebWorker;
class WebWorkerClient;
class WebMediaPlayer;
class WebMediaPlayerClient;
+class WebNode;
class WebURLRequest;
class WebURLResponse;
class WebWidget;
@@ -615,7 +616,8 @@ class WebViewDelegate : virtual public WebKit::WebWidgetClient {
// @abstract Shows a context menu with commands relevant to a specific
// element on the current page.
// @param webview The WebView sending the delegate method.
// @param node The node(s) the context menu is being invoked on
// @param x The x position of the mouse pointer (relative to the webview)
// @param y The y position of the mouse pointer (relative to the webview)
// @param link_url The absolute URL of the link that contains the node the
@@ -635,7 +637,7 @@ class WebViewDelegate : virtual public WebKit::WebWidgetClient {
// @param frame_charset which indicates the character encoding of
// the currently focused frame.
virtual void ShowContextMenu(WebView* webview,
- ContextNode node,
+ ContextNodeType node_type,
int x,
int y,
const GURL& link_url,
@@ -615,7 +616,8 @@ class WebViewDelegate : virtual public WebKit::WebWidgetClient {
// element on the current page.
// @param webview The WebView sending the delegate method.
- // @param node The node(s) the context menu is being invoked on
+ // @param node_type The type of the node(s) the context menu is being
+ // invoked on
// @param x The x position of the mouse pointer (relative to the webview)
// @param y The y position of the mouse pointer (relative to the webview)
« no previous file with comments | « webkit/glue/webview.h ('k') | webkit/glue/webview_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698